==> regina-normal_5.1.orig.tar.gz: regina-5.1/python/subcomplex/layeredchainpair.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2016, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

#include <boost/python.hpp>
#include "subcomplex/layeredchainpair.h"
#include "triangulation/dim3.h"
#include "../helpers.h"

using namespace boost::python;
using regina::LayeredChainPair;

void addLayeredChainPair() {
    class_<LayeredChainPair, bases<regina::StandardTriangulation>,
            std::auto_ptr<LayeredChainPair>, boost::noncopyable>
            ("LayeredChainPair", no_init)
        .def("clone", &LayeredChainPair::clone,
            return_value_policy<manage_new_object>())
        .def("chain", &LayeredChainPair::chain,
            return_internal_reference<>())
        .def("isLayeredChainPair", &LayeredChainPair::isLayeredChainPair,
            return_value_policy<manage_new_object>())
        .def(regina::python::add_eq_operators())
        .staticmethod("isLayeredChainPair")
    ;

    implicitly_convertible<std::auto_ptr<LayeredChainPair>,
        std::auto_ptr<regina::StandardTriangulation> >();

    scope().attr("NLayeredChainPair") = scope().attr("LayeredChainPair");
}

==> regina-normal_5.95.orig.tar.gz: regina-5.95/python/subcomplex/layeredchainpair.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2018, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

#include "../pybind11/pybind11.h"
#include "subcomplex/layeredchainpair.h"
#include "triangulation/dim3.h"
#include "../helpers.h"

using regina::LayeredChainPair;

void addLayeredChainPair(pybind11::module_& m) {
    pybind11::class_<LayeredChainPair, regina::StandardTriangulation>
            (m, "LayeredChainPair")
        .def("clone", &LayeredChainPair::clone)
        .def("chain", &LayeredChainPair::chain,
            pybind11::return_value_policy::reference_internal)
        .def_static("isLayeredChainPair", &LayeredChainPair::isLayeredChainPair)
    ;

    m.attr("NLayeredChainPair") = m.attr("LayeredChainPair");
}
